@@ -8,10 +8,12 @@ use Scalar::Util qw(refaddr blessed weaken);
 use Carp;
 use Try::Tiny ();
 
-our $VERSION = '0.060';
+our $VERSION = '0.070';
 
 our @CARP_NOT = qw(Try::Tiny Future);
 
+our $OnError = undef;
+
 ## ** lexical attributes to avoid collision of names.
 
 my %failure_handled_for = ();
@@ -51,10 +53,13 @@ sub _q_warn_failure {
     my ($self, %options) = @_;
     if($self->is_ready && $self->failure) {
         my $failure = $self->failure;
-        if($options{is_subfuture}) {
-            carp "Failure of subfuture $self may not be handled: $failure  subfuture may be lost";
+        my $message = Carp::shortmess($options{is_subfuture}
+                                      ? "Failure of subfuture $self may not be handled: $failure  subfuture may be lost"
+                                      : "Failure of $self is not handled: $failure  future is lost");
+        if(defined($OnError) && ref($OnError) eq "CODE") {
+            $OnError->($message);
         }else {
-            carp "Failure of $self is not handled: $failure  future is lost";
+            warn $message;
         }
     }
 }
@@ -246,7 +251,7 @@ almost completely compatible with Kris Kowal's Q module for JavaScript.
 L<Future::Q>'s API and documentation is designed to be self-contained,
 at least for basic usage of Futures.
 If a certain function you want is missing in this module,
-you should refer to L</Missing Methods> section and/or L<Future>.
+you should refer to L</Missing Methods and Features> section and/or L<Future>.
 (But be prepared because L<Future> has a lot of methods!)
 
 Basically a Future (in a broad meaning) represents an operation (whether it's in progress
@@ -322,11 +327,10 @@ L<Future::Q> warns you when a rejected L<Future::Q> object is destroyed without
 This is because ignoring a rejected L<Future::Q> is just as dangerous as ignoring a thrown exception.
 Any rejected L<Future::Q> object must be handled properly.
 
-When a rejected but unhandled L<Future::Q> is destroyed,
+By default
+when a rejected but unhandled L<Future::Q> is destroyed,
 the reason of the failure is printed through Perl's warning facility.
-You can capture them by setting C<$SIG{__WARN__}>.
-The warning messages can be evaluated to strings.
-(They ARE strings actually, but this may change in future versions)
+This behavior can be modified by setting C<$OnError> package variable (see below).
 
 L<Future::Q> thinks failures of the following futures are "handled".
 
@@ -357,6 +361,35 @@ in callbacks for dependent futures returned by C<wait_all()>, C<wait_any()>, C<n
 This is because there may be multiple of failed subfutures.
 It is even possible that some subfutures fail but the dependent future succeeds.
 
+=head1 PACKAGE VARIABLES
+
+You can set the following package variables to change L<Future::Q>'s behavior.
+
+=head2 $OnError
+
+A subroutine reference called when a rejected but unhandled L<Future::Q> object is destroyed.
+
+C<$OnError> is called like
+
+    $OnError->($warning_message)
+
+The C<$warning_message> can be evaluated to a human-readable string
+(It IS a string actually, but this may change in future versions).
+So you can pass the string to a logger, for example.
+
+    my $logger = ...;
+    
+    $Future::Q::OnError = sub {
+        my ($warning_message) = @_;
+        $logger->warn("Unhanlded Future: " . $warning_message);
+    };
+
+If C<$OnError> is C<undef>, which is the default,
+C<$warning_message> is printed by the built-in C<warn()> function.
+You can capture it by setting C<$SIG{__WARN__}>.
+
+
+
 =head1 CLASS METHODS
 
 In addition to all class methods in L<Future>,
@@ -655,9 +688,9 @@ This is required by the original L<Future> class.
 
 
 
-=head2 Missing Methods
+=head2 Missing Methods and Features
 
-Some methods in Q module are missing in L<Future::Q>.
+Some methods and features in Q module are missing in L<Future::Q>.
 Some of them worth noting are listed below.
 
 =over
@@ -675,7 +708,8 @@ but they are not supported in this version of L<Future::Q>.
 =item promise.done()
 
 L<Future> already has C<done()> method for a completely different meaning.
-There is no corresponding method in this version of L<Future::Q>.
+L<Future::Q> doesn't need the equivalent of Q's C<done()> method because rejected and unhandled futures are detected
+in their C<DESTROY()> method. See also L</Reporting Unhandled Failures>.
 
 =item promise.fcall() (object method)
 
@@ -690,6 +724,10 @@ Use C<< Future::Q->needs_all() >> and C<< Future::Q->wait_all() >> methods inher
 
 Use C<< Future::Q->wrap() >> method inherited from the original L<Future> class.
 
+=item Q.onerror
+
+Use C<$OnError> package variable, although it is not exactly the same as C<Q.onerror>. See also L</Reporting Unhandled Failures>.
+
 =back
 
 
